function [Vout]=Voltage_Out(choice,q,a,h,RL,Reff,NR,Vin,G_par,G_per);
% [Vout]=Voltage_Out(choice,q,a,h,RL,Reff,NR,Vin,G_par,G_per); 
%
%   choice   : 1-small / 2-large deflection
%   Pressure : Applied Pressure (Pa)
%   a        : Diapharm Diameter (m)/ Plate Width (m)
%   RL       : Effective Length (m)
%   Reff     : Effective Length (m)
%   NR       : Non-Effective Length (m)

clear A B E F
v=0.27;
EE=150e9;

P=q;
if choice == 4
  w0_coeff(1)=31.1*EE*h/(a^4);
  w0_coeff(2)=0;
  w0_coeff(3)=71.3*EE*h^3/(a^4);
  w0_coeff(4)=-q;
  ww0=roots(w0_coeff);
  for i=1:3
    if ((ww0(i)*ww0(i))>0) & ((ww0(i)*q)>0)
      w0=ww0(i);
    end;  
  end;
  P=71.3*w0*EE*h^3/(a^4);  % q(1)  (q=q(1)+q(2)
end;

% Constant Calcualation--- For Square Plate
if choice == 3 | choice == 4    
  for i=1:2:51    % For a=b square plate
    A(i)=i*pi/2;       A(i+1)=(i+1)*pi/2;
    B(i)=i*pi/2;       B(i+1)=(i+1)*pi/2;
    E(i)=1;            E(i+1)=0;
    F(i)=1;            F(i+1)=0;
  end
  Eold=1000;

  % === Iteration Calculation for Em and Fm ===
  while abs(E(51)-Eold) > 1e-12
    Eold=E(51);
    for n=1:2:51
      Esum=0;   Fsum=0;
      
      for m=1:2:51
        Fsum=Fsum+F(m)/(m^3*((1+(n/m)^2)^2));
      end;
      temp=4*P*a*a/(pi^3*n^4)*(A(n)/(cosh(A(n))^2)-tanh(A(n)))-8*n*Fsum/pi;
      E(n)=n/(tanh(A(n))+A(n)/cosh(A(n))^2)*temp;
    
      for m=1:2:51
        Esum=Esum+E(m)/(m^3*(1+(n/m)^2)^2);
      end;
      temp=4*P*a*a/(pi^3*n^4)*(B(n)/(cosh(B(n))^2)-tanh(B(n)))-8*n*Esum/pi;
      F(n)=n/(tanh(B(n))+B(n)/cosh(B(n))^2)*temp;    
    end
  end
end;

Reff_sen=0;
N=40;           % # for Resistor Sensitive Integral 
distance=RL/N;

%--- Strain Variation --- Integral for Resistor sensitive
for j=1:N
  r=a/2-distance*j;  
  
  %===== Circular Plate =====   
  if choice == 1         %-- SMALL deflection 
    [el,et]=sc_strain(P,r,h,a/2);   
  elseif choice == 2     %-- Large deflection
    [el,et]=lc_strain(P,r,h,a/2);    

  %===== Square Plate =====
  elseif choice == 3     %-- SMALL deflection
    [el,et]=ss_strain(P,r,h,a,A,B,E,F);
  else                   %-- LARGE deflection
    [el1,et1]=ss_strain(P,r,h,a,A,B,E,F);
    [el2,et2]=ls_strain(r,h,a,w0);
    el=el1+el2;
    et=et1+et2;
  end;
  R_sen=G_par*el+G_per*et;
  Reff_sen=Reff_sen+R_sen*distance;

end;

if RL==0
  Vout=0;  
else
  Reff_sen=Reff_sen/RL;
  Reff_del=Reff*Reff_sen;  
  Vout=Reff_del/(2*(Reff+NR)+Reff_del)*Vin;
end;

return;
