function [el,et]=lc_strain(q,r,h,a);
%  [el,et]=lc_strain(q,r,h,a) 
%
%   Strain Distribution in thin circular plate. < LARGE DEFLECTION >
%
%    q : distributed load (Pa) (1psi=6895 Pa)
%    r : raidal location 
%    h : plate thickness 
%    a : plate RADIUS
%    el : longtudial strain (radial direction)
%    et : tangetial strain  (circumferential direction)
%   

v=0.27;       % Poisson Ratio
EE=150e9;     % Young's Modulus
D=EE*h^3/(12*(1-v*v));

z=-h/2;
aa=a*a;
rr=r*r;

w_coef(1)=0.5037214/h/h;  % for the case of v=0.27
w_coef(2)=0;
w_coef(3)=1;
w_coef(4)=-q*a^4/64/D;
w0=roots(w_coef);

for i=1:3
  if (w0(i)^2)>=0
    ww0=w0(i);
    C1=1.185*ww0*ww0/a/a/a;
    C2=-1.75*ww0*ww0/a/a/a/a;
  end  
end

el1=-z*(8*ww0*rr/aa/aa-4*ww0*(1-rr/aa)/aa);
el2=(a-r)*(C1+C2*r)-r*(C1+C2*r)+r*(a-r)*C2;;  
el3=8*ww0*ww0*rr*(1-rr/aa)^2/aa/aa;           

el=el1+el2+el3;

et1=4*z*ww0*(1-rr/aa)/aa;
et2=(a-r)*(C1+C2*r);
et=et1+et2;

return;
