function opt(choice,in,Si_data);
%   SubFunction for Effective Length
%     choice : 1. small-circular/  2.large-circular
%              3. small-square  /  4.large-square
%      in(1) : Pressure(psi)
%      in(2) : turn
%      in(3) : Rw, Resistor Width (um)
%      in(4) : a , Plate Diameter/Width (um)
%      in(5) : h , Plate Thickness(um)
%      in(6) : sheet_r, Sheet Resistance

clear Vout;

q=in(1)*6895;
turn=in(2);
Rw=in(3)*1e-6;
a =in(4)*1e-6;        
h =in(5)*1e-6;       
r_sheet=in(6);
Temp=in(8)+273;

% Resistor Parameters. -----
%    RL     : Length of the Resistor
%    RLsub  : Length of the Resistor going into the substrate
%    Rw     : Width of the Resistor
%    tl, tw : length/width of the turn around resistor
%    cl, cw : length/width of the contact pad before metal
tl=5e-6;     tw=5e-6;  
cl=8e-6;     cw=6e-6;
RLsub=2e-6;
PR=200 ;          % Parasitic Resistance  
Vin=5e3;          % input Voltage

% Programming Calculation
N=50;         % Step for RL used to be 100
div=a/2/N;
E=150e9;
v=0.27;

% Room Temp Piezoresistance Coeff. in the (100) plane  - from previous thesis
PI_l_300=1e-12*153.9;
PI_t_300=1e-12*-87.3;
P_NT=piezo(Si_data(2),Temp,Si_data(1));

%  PiezoResistive Coeff. in longutidual and transverse direction  
PI_l=PI_l_300*P_NT;
PI_t=PI_t_300*P_NT;

%  Resistor Sensitivity Calculation
F_par=E*(PI_l+v*PI_t)/(1-v*v);
F_per=E*(PI_t+v*PI_l)/(1-v*v);
G_par=F_par+1/(1-v);
G_per=F_per+(1-2*v)/(1-v);

% Varying Effective Length
for j=1:N+1
  RL=div*(j-1);
  R =r_sheet*( 2*turn*(RL+RLsub)/Rw + (2*turn-1)*tl/tw + 2*cl/cw )+PR;
  NR=r_sheet*( 2*turn*(RLsub)/Rw + (2*turn-1)*tl/tw + 2*cl/cw )+PR;
  Reff=R-NR;

  if RL==0 
    Vout(j)=0;
  else
    Vout(j)=Voltage_Out(choice,q,a,h,RL,Reff,NR,Vin,G_par,G_per);
  end;

  x(j)=RL*1e6;   % effective length in unit :um
end;

%if choice == 1 | choice ==3
%  plot(x,Vout);
%else 
%  plot(x,Vout,'r-.');
%end;

plot_choice=round(mod(rand(1)*10,3));
if plot_choice==0
  plot(x,Vout,'b');
elseif plot_choice==1
  plot(x,Vout,'r-.');
elseif plot_choice==2
  plot(x,Vout,'m--');
else
  plot(x,Vout,'k:');
end;



xlabel('Effective Length (um)');
ylabel('Output Voltage (mVolt)');

return;
