function squ_dist(choice,in);
%   SubFunction for Strain Distribution in Square Plate
%     choice : 1. small/  2.large/  3.Lin's
%      in(1) : Pressure(psi)
%      in(2) : turn
%      in(3) : Rw, Resistor Width (um)
%      in(4) : a , Plate Diameter/Width (um)
%      in(5) : h , Plate Thickness(um)

q=in(1)*6895;
turn=in(2);
Rw=in(3)*1e-6;
a =in(4)*1e-6;        
h =in(5)*1e-6;       
 
v=0.27;       % Poisson Ratio
EE=150e9;     % Young's Modulus
D=EE*h^3/(12*(1-v^2));

z=-h/2;
P=q;

if choice == 2
  w0_coeff(1)=31.1*EE*h/(a^4);
  w0_coeff(2)=0;
  w0_coeff(3)=71.3*EE*h^3/(a^4);
  w0_coeff(4)=-q;
  ww0=roots(w0_coeff);
  for i=1:3
    if ((ww0(i)*ww0(i))>0) & ((ww0(i)*q)>0)
      w0=ww0(i);
    end;  
  end;
  P=71.3*w0*EE*h^3/(a^4);    % q(1); for bending
end;

if choice == 1 | choice == 2
  for i=1:2:51
    A(i)=i*pi/2;       A(i+1)=(i+1)*pi/2;
    B(i)=i*pi/2;       B(i+1)=(i+1)*pi/2;
    E(i)=1;            E(i+1)=0;
    F(i)=1;            F(i+1)=0;
  end
  Eold=1000;

  % === Iteration Calculation for Em and Fm ===
  while abs(E(51)-Eold) > 1e-12
    Eold=E(51);
    for n=1:2:51
      Esum=0;   Fsum=0;
      
      for m=1:2:51
        Fsum=Fsum+F(m)/(m^3*(1+(n/m)^2)^2);
      end;
      temp=4*P*a*a/(pi^3*n^4)*(A(n)/(cosh(A(n))^2)-tanh(A(n)))-8*n*Fsum/pi;
      E(n)=n/(tanh(A(n))+A(n)/cosh(A(n))^2)*temp;
    
      for m=1:2:51
        Esum=Esum+E(m)/(m^3*(1+(n/m)^2)^2);
      end;
      temp=4*P*a*a/(pi^3*n^4)*(B(n)/(cosh(B(n))^2)-tanh(B(n)))-8*n*Esum/pi;
      F(n)=n/(tanh(B(n))+B(n)/cosh(B(n))^2)*temp;    
    end
  end
end;

N=100;       % divide x-axis into N sections.
div=a/2/N;

for j=1:N+1
  x=(j-1)*div;
  xx(j)=x;
  if choice == 1
% === SMALL deflection ===
    [ex(j),ey(j)]  =ss_strain(P,x,h,a,A,B,E,F);
  elseif choice == 2

% === LARGE deflection q=qq(1)+qq(2) ===
%     qq(1) : bending
%     qq(2) : membrane theory
    [ex1(j),ey1(j)]=ss_strain(P,x,h,a,A,B,E,F);
    [ex2(j),ey2(j)]=ls_strain(x,h,a,w0);
    ex(j)=ex1(j)+ex2(j);
    ey(j)=ey1(j)+ey2(j);
  elseif choice ==3
    [ex(j),ey(j)]=ls_strain1(x,h,a,P);
  end;
end;

if choice == 1
  plot(xx*1e6,ex,xx*1e6,ey,'r');
elseif choice == 2
  plot(xx*1e6,ex,'-.',xx*1e6,ey,'c-.');
end;

xlabel('X-Axis (\mum)');  ylabel('Strain \epsilon');
title('Central Strain Distribution');
legend('\epsilon_x','\epsilon_y');

