function [strain_x,strain_y]=ss_strain(q,x,h,a,A,B,E,F);
% [strain_x,strain_y]=ss_strain(q,x,h,a,A,B,E,F);          
%    Strain_Distribution in SQUARE Plate via SMALL deflection @ Y=0 
%      P  : Pressure(Pa)
%      x  : Location in X-Axis
%      h  : Plate Thickness(um)
%      a  : the length of square plate

v=0.27;
EE=150e9;     % Young's Modulus
D=EE*h^3/(12*(1-v^2));

y=0;
z=-h/2;
b=a;

% deflection in z direction, w.
w1_c =4*q*a*a*a*a/(pi^5*D);   % constant
w2_c =-a*a/(2*pi*pi*D);       % constant
w3_c =-b*b/(2*pi*pi*D);       % constant

% =====  strain_calculation =====
strain_x=0;   strain_y=0;
w1_dxx=0;  w1_dyy=0;
w2_dxx=0;  w2_dyy=0;
w3_dxx=0;  w3_dyy=0;

for m=1:2:51
  % Simified Sympolic
  sign=(-1)^((m-1)/2);
  mpia=m*pi/a;    mpib=m*pi/b;
  Am=A(m);        Bm=B(m);
  
  w1_dxx=w1_dxx-sign/(m^5)*(mpia^2*cos(mpia*x))*...
     ( 1-(Am*tanh(Am)+2)*(cosh(mpia*y)/(2*cosh(Am)))+...
     (mpia*y*sinh(mpia*y))/(2*cosh(Am)) );
  w1_dyy=w1_dyy+sign/(m^5)*cos(mpia*x)*mpia^2/(2*cosh(Am))*...
     ( -(Am*tanh(Am)+2)*cosh(mpia*y) + 2*cosh(mpia*y)+ mpia*y*sinh(mpia*y) );

  w2_dxx=w2_dxx-sign*E(m)/(m^2*cosh(Am))*mpia^2*cos(mpia*x)*...
     (mpia*y*sinh(mpia*y)-Am*tanh(Am)*cosh(mpia*y));
  w2_dyy=w2_dyy+sign*E(m)/(m^2*cosh(Am))*cos(mpia*x)*(mpia^2)*...
     (2*cosh(mpia*y)+mpia*y*sinh(mpia*y)-Am*tanh(Am)*cosh(mpia*y));
  
  w3_dxx=w3_dxx+sign*F(m)/(m^2*cosh(Bm))*cos(mpib*y)*(mpib^2)*...
     (2*cosh(mpib*x)+mpib*x*sinh(mpib*x)-Bm*tanh(Bm)*cosh(mpib*x));
  w3_dyy=w3_dyy-sign*F(m)/(m^2*cosh(Bm))*mpib^2*cos(mpib*y)*...
     (mpib*x*sinh(mpib*x)-Bm*tanh(Bm)*cosh(mpib*x));
end;

strain_x=(w1_dxx*w1_c+w2_dxx*w2_c+w3_dxx*w3_c)*(-z);
strain_y=(w1_dyy*w1_c+w2_dyy*w2_c+w3_dyy*w3_c)*(-z);

return;
